@@ -1,4 +1,6 @@
 package Devel::ebug::Backend::Plugin::Commands;
+use strict;
+use warnings;
 
 sub register_commands {
   return ( commands    => { sub => \&commands }, );
